Struct Value
struct Value(_)
A value used in a list of Fields.
The value has to be a sequence of one or more alphanumerical strings
separated by -.
Each part of the sequence has to be no shorter than three characters and no
longer than 8.
Examples
use Value;
"hybrid"..expect;
"hybrid-foobar"..expect;
"no"..expect_err;
Implementations
impl Value
impl Clone for Value
fn clone(self: &Self) -> Value
impl Debug for Value
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Default for Value
fn default() -> Value
impl Display for Value
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Eq for Value
impl Freeze for Value
impl Hash for Value
fn hash<__H: $crate::hash::Hasher>(self: &Self, state: &mut __H)
impl Ord for Value
fn cmp(self: &Self, other: &Value) -> Ordering
impl PartialEq for Value
fn eq(self: &Self, other: &Value) -> bool
impl PartialOrd for Value
fn partial_cmp(self: &Self, other: &Value) -> Option<Ordering>
impl RefUnwindSafe for Value
impl Send for Value
impl StructuralPartialEq for Value
impl Sync for Value
impl Unpin for Value
impl UnsafeUnpin for Value
impl UnwindSafe for Value
impl Writeable for Value
fn write_to<W: core::fmt::Write + ?Sized>(self: &Self, sink: &mut W) -> Resultfn writeable_length_hint(self: &Self) -> LengthHint
impl<T> Any for Value
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for Value
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for Value
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for Value
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> ErasedDestructor for Value
impl<T> From for Value
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToOwned for Value
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T> ToString for Value
fn to_string(self: &Self) -> String
impl<T, U> Into for Value
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for Value
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for Value
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>